RawHandle

Trait RawHandle 

pub trait RawHandle {
    type Handle;

    // Required method
    fn handle(&self) -> Self::Handle;
}

Required Associated Types

Required Methods

fn handle(&self) -> Self::Handle

Care should be taken to use the returned ESP-IDF driver raw handle only while the driver is still alive, so as to avoid use-after-free errors.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<R> RawHandle for &R
where R: RawHandle,

Source

type Handle = <R as RawHandle>::Handle

Source

fn handle(&self) -> Self::Handle

Source

impl<R> RawHandle for &mut R
where R: RawHandle,

Source

type Handle = <R as RawHandle>::Handle

Source

fn handle(&self) -> Self::Handle

Implementors

Source

impl RawHandle for esp_idf_svc::http::client::EspHttpConnection

Source

impl RawHandle for esp_idf_svc::http::server::EspHttpConnection<'_>

Source

impl RawHandle for EspHttpRawConnection<'_>

Source

impl RawHandle for EspHttpServer<'_>

Source

type Handle = *mut c_void

Source

impl RawHandle for EspMqttClient<'_>

Source

impl RawHandle for EspNetif

Source

impl RawHandle for EspNvs<NvsCustom>

Source

type Handle = u32

Source

impl RawHandle for EspNvs<NvsDefault>

Source

type Handle = u32

Source

impl RawHandle for EspNvs<NvsEncrypted>

Source

type Handle = u32

Source

impl RawHandle for EspNvsPartition<NvsCustom>

Source

type Handle = *const u8

Source

impl RawHandle for EspNvsPartition<NvsEncrypted>

Source

type Handle = *const u8

Source

impl RawHandle for EspPartition

Source

impl RawHandle for EspTimer<'_>

Source

impl<D, T> RawHandle for EspAsyncSubscription<D, User<T>>

Source

type Handle = *mut c_void

Source

impl<T> RawHandle for EspEth<'_, T>

Available on esp_idf_comp_esp_netif_enabled only.
Source

impl<T> RawHandle for EspEventLoop<User<T>>

Source

type Handle = *mut c_void

Source

impl<T> RawHandle for EspSubscription<'_, User<T>>

Source

type Handle = *mut c_void

Source

impl<T> RawHandle for EspWlPartition<T>

Source

type Handle = i32

Source

impl<T> RawHandle for EthDriver<'_, T>

Source

type Handle = *mut c_void